# Begin OSD conversion.  Run on each node that has OSDS

function repair_cephfs () {

  echo "Beginning repair process for cephfs"
  echo "Running cephfs-journal-tool event recover_dentries summary"
  cephfs-journal-tool --rank=cephfs:0 event recover_dentries summary

  echo "Running cephfs-journal-tool journal reset"
  cephfs-journal-tool --rank=cephfs:0 journal reset

  echo "ceph mds repaired cephfs:0"
  ceph mds repaired cephfs:0
}

function upgrade_mds () {

  ceph fs ls
  ceph orch ps --daemon-type mds
  ceph fs status

  date=$(date +%m%e.%H%M)
  echo "Backing up the Ceph MDS Journal"
  cephfs-journal-tool --rank cephfs:all  journal export /root/backup.$date.bin

  export standby_mdss=$(ceph fs dump -f json-pretty|jq -r '.standbys|map(.name)|join(" ")')
  export active_mds=$(ceph fs status -f json-pretty|jq -r '.mdsmap[]|select(.state=="active")|.name')
  export mds_cluster="$active_mds $standby_mdss"

  ceph fs set cephfs max_mds 1
  #ceph fs set cephfs down true
  ceph fs set cephfs allow_standby_replay false
  ceph fs set cephfs standby_count_wanted 0

  echo "Active MDS is: $active_mds"
  echo "Standby MDS(s) are: $standby_mdss"

  for host in $standby_mdss
  do
   echo "Stopping legacy standby mds service on $host"
   ssh $host "systemctl stop ceph-mds.target"
  done

  echo "sleeping for 60 seconds to allow the standby MDS to fully stop"
  sleep 60

  echo "Adopting active standby mds service on $host"
  ssh $active_mds "cephadm --image $registry/ceph/ceph:v15.2.8 adopt --style legacy --name mds.$active_mds" --skip-pull

for host in $standby_mdss
  do
   echo "Adopting legacy standby mds service on $host"
   ssh $host "cephadm --image $registry/ceph/ceph:v15.2.8 adopt --style legacy --name mds.$host" --skip-pull
  done

  ceph fs set cephfs standby_count_wanted 2
  #ceph fs set cephfs allow_standby_replay true
  ceph orch apply mds cephfs --placement="3 $(ceph node ls |jq -r '.mon|map(.[])|join(" ")')"

  read -t 60 -p "Pausing 60 seconds to allow the new active MDS to start completely..."

  output=$(ceph -s 2>&1 | grep 'filesystem is degraded')
  echo "Checking to see if filesystems are healthy"
  rc=$?
  if [ "$rc" -eq 0 ]; then

    repair_cephfs
  fi

  #ceph fs set cephfs down false
  ceph orch ps --daemon-type mds
}
