#!/bin/bash

all_workers=$(kubectl get nodes | grep ncn-w | awk '{print $1}')
kea_node=$(kubectl get po -n services -l 'app.kubernetes.io/name=cray-dhcp-kea' -o wide | grep -v NAME | awk '{print $7}')
nexus_node=$(kubectl get po -n nexus -l 'app=nexus' -o wide | grep -v NAME | awk '{print $7}')
conman_node=$(kubectl get po -n services -l 'app.kubernetes.io/name=cray-conman' -o wide | grep -v NAME | awk '{print $7}')

echo "Critical pod locations:"
echo ""
echo "  kea pod is running on:    $kea_node"
echo "  nexus pod is running on:  $nexus_node"
echo "  conman pod is running on: $conman_node"
echo ""

found_empty_worker=0
for worker in $all_workers; do
  if [ "$worker" == "$kea_node" ] || [ "$worker" == "$nexus_node" ] || [ "$worker" == "$conman_node" ]; then
    continue
  fi
  echo "NOTE: In order to minimize pod moves, it is recommended to first upgrade $worker first."
  found_empty_worker=1
  break
done

if [ "$found_empty_worker" -eq 0 ]; then
  echo "NOTE: There isn't a worker not running one of the critical services, so choose whatever order you wish."
fi

echo "In order to force a pod to move to a given node, you can taint all other nodes:"
echo ""
echo "  To taint a node:    kubectl taint nodes <node> key=value:NoSchedule"
echo "  To untaint a node:  kubectl taint nodes <node> key=value:NoSchedule-"
echo ""
echo "  To untaint all worker nodes: "
echo ""
echo "   for node in \$(kubectl get nodes | grep ncn-w | awk '{print \$1}'); \\"
echo '     do kubectl taint nodes $node key=value:NoSchedule-; \'
echo '   done'
